@@ -3,7 +3,7 @@ import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
 from sklearn.manifold import MDS
-from shapash.explainer.smart_explainer import SmartExplainer
+from shapash import SmartExplainer
 
 
 class Consistency():
@@ -82,15 +82,10 @@ class Consistency():
             Dict whose keys are method names and values are the corresponding contributions
         """
         contributions = {}
-        xpl = SmartExplainer()
 
         for backend in methods:
-            xpl.compile(
-                x=x,
-                model=model,
-                preprocessing=preprocessing,
-                backend=backend
-            )
+            xpl = SmartExplainer(model=model, preprocessing=preprocessing, backend=backend)
+            xpl.compile(x=x)
             if xpl._case == "classification" and len(xpl._classes) == 2:
                 contributions[backend] = xpl.contributions[1]
             elif xpl._case == "classification" and len(xpl._classes) > 2:
