@@ -5,11 +5,8 @@ from shapash.utils.check import check_consistency_model_features, check_consiste
 from shapash.utils.check import check_model, check_preprocessing, check_preprocessing_options
 from shapash.utils.check import check_label_dict, check_mask_params, check_ypred, check_contribution_object,\
                                 check_features_name
-from .smart_state import SmartState
-from .multi_decorator import MultiDecorator
 import pandas as pd
 from shapash.utils.transform import adapt_contributions
-from shapash.utils.shap_backend import check_explainer, shap_contributions
 from shapash.manipulation.select_lines import keep_right_contributions
 from shapash.utils.model import predict_proba
 from shapash.utils.io import save_pickle
@@ -56,8 +53,8 @@ class SmartPredictor :
         Dictionary mapping technical feature names to domain names.
     model: model object
         model used to check the different values of target estimate predict_proba
-    explainer: explainer object
-        explainer must be a shap object (TreeExplainer, LinearExplainer, KernelExplainer)
+    backend: str or backend object
+        backend (explainer) used to compute contributions
     columns_dict: dict
         Dictionary mapping integer column number (in the same order of the trained dataset) to technical feature names.
     features_types: dict
@@ -67,7 +64,7 @@ class SmartPredictor :
     preprocessing: category_encoders, ColumnTransformer, list or dict (optional)
         The processing apply to the original data.
     postprocessing: dict (optional)
-        Dictionary of postprocessing modifications to apply in x_pred dataframe.
+        Dictionary of postprocessing modifications to apply in x_init dataframe.
     _case: string
         String that informs if the model used is for classification or regression problem.
     _classes: list, None
@@ -81,7 +78,7 @@ class SmartPredictor :
     -------
     >>> predictor = SmartPredictor(features_dict=my_features_dict,
     >>>                             model=my_model,
-    >>>                             explainer=my_explainer,
+    >>>                             backend=my_backend,
     >>>                             columns_dict=my_columns_dict,
     >>>                             features_types=my_features_type_dict,
     >>>                             label_dict=my_label_dict,
@@ -97,7 +94,7 @@ class SmartPredictor :
     """
 
     def __init__(self, features_dict, model,
-                 columns_dict, explainer, features_types,
+                 columns_dict, backend, features_types,
                  label_dict=None, preprocessing=None,
                  postprocessing=None,
                  features_groups=None,
@@ -120,7 +117,7 @@ class SmartPredictor :
 
         self.model = model
         self._case, self._classes = self.check_model()
-        self.explainer = self.check_explainer(explainer)
+        self.backend = backend
         self.preprocessing = preprocessing
         self.check_preprocessing()
         self.features_dict = features_dict
@@ -142,7 +139,7 @@ class SmartPredictor :
     def check_model(self):
         """
         Check if model has a predict_proba method is a one column dataframe of integer or float
-        and if y_pred index matches x_pred index
+        and if y_pred index matches x_init index
 
         Returns
         -------
@@ -224,7 +221,7 @@ class SmartPredictor :
                 use_groups=False
             )
         else:
-            self.data["ypred"], self.data["contributions"]  = self.compute_contributions(use_groups=False)
+            self.data["ypred"], self.data["contributions"] = self.compute_contributions(use_groups=False)
 
         if self.features_groups is not None:
             self._add_groups_input()
@@ -235,8 +232,8 @@ class SmartPredictor :
         and stores it in data_groups attribute
         """
         self.data_groups = dict()
-        self.data_groups['x_postprocessed'] = create_grouped_features_values(x_pred=self.data["x_postprocessed"],
-                                                                             x_init=self.data["x_preprocessed"],
+        self.data_groups['x_postprocessed'] = create_grouped_features_values(x_init=self.data["x_postprocessed"],
+                                                                             x_encoded=self.data["x_preprocessed"],
                                                                              preprocessing=self.preprocessing,
                                                                              features_groups=self.features_groups,
                                                                              features_dict=self.features_dict,
@@ -340,27 +337,6 @@ class SmartPredictor :
         """
         return check_ypred(self.data["x"],ypred)
 
-    def choose_state(self, contributions):
-        """
-        Select implementation of the smart predictor. Typically check if it is a
-        multi-class problem, in which case the implementation should be adapted
-        to lists of contributions.
-
-        Parameters
-        ----------
-        contributions : object
-            Local contributions. Could also be a list of local contributions.
-
-        Returns
-        -------
-        object
-            SmartState or SmartMultiState, depending on the nature of the input.
-        """
-        if isinstance(contributions, list):
-            return MultiDecorator(SmartState())
-        else:
-            return SmartState()
-
     def adapt_contributions(self, contributions):
         """
         If _case is "classification" and contributions a np.array or pd.DataFrame
@@ -378,23 +354,6 @@ class SmartPredictor :
         """
         return adapt_contributions(self._case, contributions)
 
-    def validate_contributions(self, contributions):
-        """
-        Check len of list if _case is "classification"
-        Check contributions object type if _case is "regression"
-        Check type of contributions and transform into (list of) pd.Dataframe if necessary
-
-        Parameters
-        ----------
-        contributions : pandas.DataFrame, np.ndarray or list
-
-        Returns
-        -------
-            pandas.DataFrame or list
-        """
-        check_contribution_object(self._case, self._classes, contributions)
-        return self.state.validate_contributions(contributions, self.data["x_preprocessed"])
-
     def check_contributions(self, contributions):
         """
         Check if contributions and prediction set match in terms of shape and index.
@@ -404,7 +363,7 @@ class SmartPredictor :
         else:
             x = self.data["x"]
 
-        if not self.state.check_contributions(contributions, x, features_names=False):
+        if not self.backend.state.check_contributions(contributions, x, features_names=False):
             raise ValueError(
                 """
                 Prediction set and contributions should have exactly the same number of lines
@@ -413,7 +372,6 @@ class SmartPredictor :
                 """
             )
 
-
     def clean_data(self, x):
         """
         Clean data stored if x is defined and not None.
@@ -435,12 +393,6 @@ class SmartPredictor :
                 "x_postprocessed": None
                 }
 
-    def check_explainer(self, explainer):
-        """
-        Check if explainer class correspond to a shap explainer object
-        """
-        return check_explainer(explainer)
-
     def predict_proba(self):
         """
         The predict_proba compute the probabilities predicted for each x row defined in add_input.
@@ -492,15 +444,16 @@ class SmartPredictor :
             self.predict()
 
         if contributions is None:
-            contributions, explainer = shap_contributions(self.model,
-                                               self.data["x_preprocessed"],
-                                               self.explainer)
-        adapt_contrib = self.adapt_contributions(contributions)
-        self.state = self.choose_state(adapt_contrib)
-        contributions = self.validate_contributions(adapt_contrib)
-        contributions = self.apply_preprocessing_for_contributions(contributions,
-                                                                   self.preprocessing
-                                                                   )
+            explain_data = self.backend.run_explainer(x=self.data["x_preprocessed"])
+            contributions = self.backend.get_local_contributions(
+                explain_data=explain_data,
+                x=self.data["x_preprocessed"]
+            )
+        else:
+            contributions = self.backend.format_and_aggregate_local_contributions(
+                x=self.data["x_preprocessed"],
+                contributions=contributions
+            )
         self.check_contributions(contributions)
         proba_values = self.predict_proba() if self._case == "classification" else None
         y_pred, match_contrib = keep_right_contributions(self.data["ypred_init"], contributions,
@@ -538,30 +491,6 @@ class SmartPredictor :
         y_pred, detail_contrib = self.compute_contributions(contributions=contributions, use_groups=use_groups)
         return pd.concat([y_pred, detail_contrib], axis=1)
 
-    def apply_preprocessing_for_contributions(self, contributions, preprocessing=None):
-        """
-        Reconstruct contributions for original features, taken into account a preprocessing.
-
-        Parameters
-        ----------
-        contributions : object
-            Local contributions, or list of local contributions.
-        preprocessing : object
-            Encoder taken from scikit-learn or category_encoders
-
-        Returns
-        -------
-        object
-            Reconstructed local contributions in the original space. Can be a list.
-        """
-        if preprocessing:
-            return self.state.inverse_transform_contributions(
-                contributions,
-                preprocessing
-            )
-        else:
-            return contributions
-
     def save(self, path):
         """
         Save method allows users to save SmartPredictor object on disk using a pickle file.
@@ -581,12 +510,7 @@ class SmartPredictor :
         >>> from shapash.utils.load_smartpredictor import load_smartpredictor
         >>> predictor_load = load_smartpredictor('path_to_pkl/predictor.pkl')
         """
-        dict_to_save = {}
-        for att in self.__dict__.keys():
-            if (isinstance(getattr(self, att), (list, dict, pd.DataFrame, pd.Series, type(None))) or att == "model"
-                or att == "explainer" or att == "preprocessing") and not att == "data" :
-                dict_to_save.update({att: getattr(self, att)})
-        save_pickle(dict_to_save, path)
+        save_pickle(self, path)
 
     def apply_preprocessing(self):
         """
@@ -802,7 +726,7 @@ class SmartPredictor :
         Returns
         -------
         pandas.Dataframe
-            Returns x_pred if postprocessing is empty, modified dataframe otherwise.
+            Returns x_init if postprocessing is empty, modified dataframe otherwise.
         """
         if self.postprocessing:
             return apply_postprocessing(self.data["x"], self.postprocessing)
@@ -846,13 +770,14 @@ class SmartPredictor :
             if str(type(enc)) in columntransformer:
                 raise ValueError("SmartPredictor can't switch to SmartExplainer for ColumnTransformer preprocessing.")
 
-        xpl = shapash.explainer.smart_explainer.SmartExplainer(features_dict=copy.deepcopy(self.features_dict),
-                                                               label_dict=copy.deepcopy(self.label_dict))
-        xpl.compile(x=copy.deepcopy(self.data["x_preprocessed"]),
-                    model=self.model,
-                    explainer=self.explainer,
-                    y_pred=copy.deepcopy(self.data["ypred_init"]),
-                    preprocessing=self.preprocessing,
-                    postprocessing=self.postprocessing,
-                    features_groups=self.features_groups)
+        xpl = shapash.explainer.smart_explainer.SmartExplainer(
+            model=self.model,
+            backend=self.backend,
+            preprocessing=self.preprocessing,
+            postprocessing=self.postprocessing,
+            features_groups=self.features_groups,
+            features_dict=copy.deepcopy(self.features_dict),
+            label_dict=copy.deepcopy(self.label_dict)
+        )
+        xpl.compile(x=copy.deepcopy(self.data["x_preprocessed"]), y_pred=copy.deepcopy(self.data["ypred_init"]))
         return xpl
